@@ -13,6 +13,11 @@ func Nushell(completers []string) string {
 	snippet := `%v%v
 
 let carapace_completer = {|spans|
+  load-env {
+  	CARAPACE_SHELL_BUILTINS: (help commands | where category != "" | get name | each { split row " " | first } | uniq  | str join "\n")
+  	CARAPACE_SHELL_FUNCTIONS: (help commands | where category == "" | get name | each { split row " " | first } | uniq  | str join "\n")
+  }
+
   # if the current command is an alias, get it's expansion
   let expanded_alias = (scope aliases | where name == $spans.0 | $in.0?.expansion?)
 
