@@ -2,11 +2,12 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
+	"github.com/carapace-sh/carapace-bin/pkg/actions/tools/adb"
 	"github.com/spf13/cobra"
 )
 
 var pushCmd = &cobra.Command{
-	Use:   "push",
+	Use:   "push [–sync] [-z ALGORITHM] [-Z] LOCAL... REMOTE",
 	Short: "copy local files/directories to device",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
@@ -24,5 +25,15 @@ func init() {
 		"z": carapace.ActionValues("any", "none", "brotli"),
 	})
 
-	carapace.Gen(pushCmd).PositionalAnyCompletion(carapace.ActionFiles())
+	carapace.Gen(pushCmd).PositionalCompletion(
+		carapace.ActionFiles(),
+	)
+
+	carapace.Gen(pushCmd).PositionalAnyCompletion(
+		carapace.Batch(
+			carapace.ActionFiles().FilterArgs(),
+			adb.ActionFiles(),
+		).ToA(),
+	)
+
 }
