@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"github.com/carapace-sh/carapace"
+	"github.com/carapace-sh/carapace-bin/pkg/actions/tools/adb"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
 )
@@ -16,6 +17,7 @@ var rootCmd = &cobra.Command{
 func Execute() error {
 	return rootCmd.Execute()
 }
+
 func init() {
 	carapace.Gen(rootCmd).Standalone()
 
@@ -28,6 +30,10 @@ func init() {
 	rootCmd.Flags().StringS("s", "s", "", "use device with given serial (overrides $ANDROID_SERIAL)")
 	rootCmd.Flags().StringS("t", "t", "", "use device with given transport id")
 
+	carapace.Gen(rootCmd).FlagCompletion(carapace.ActionMap{
+		"s": adb.ActionDevices(),
+	})
+
 	carapace.Gen(rootCmd).PreInvoke(func(cmd *cobra.Command, _ *pflag.Flag, action carapace.Action) carapace.Action {
 		return carapace.ActionCallback(func(c carapace.Context) carapace.Action {
 			if f := cmd.Flag("s"); f.Changed {
