@@ -15,11 +15,13 @@ func init() {
 	carapace.Gen(generateLockfileCmd).Standalone()
 
 	generateLockfileCmd.Flags().BoolP("help", "h", false, "Print help")
-	generateLockfileCmd.Flags().Bool("ignore-rust-version", false, "Ignore `rust-version` specification in packages (unstable)")
+	generateLockfileCmd.Flags().Bool("ignore-rust-version", false, "Ignore `rust-version` specification in packages")
+	generateLockfileCmd.Flags().String("lockfile-path", "", "Path to Cargo.lock (unstable)")
 	generateLockfileCmd.Flags().String("manifest-path", "", "Path to Cargo.toml")
 	rootCmd.AddCommand(generateLockfileCmd)
 
 	carapace.Gen(generateLockfileCmd).FlagCompletion(carapace.ActionMap{
+		"lockfile-path": carapace.ActionFiles(),
 		"manifest-path": carapace.ActionFiles(),
 	})
 }
