@@ -19,12 +19,14 @@ func init() {
 	removeCmd.Flags().Bool("dev", false, "Remove from dev-dependencies")
 	removeCmd.Flags().BoolP("dry-run", "n", false, "Don't actually write the manifest")
 	removeCmd.Flags().BoolP("help", "h", false, "Print help")
+	removeCmd.Flags().String("lockfile-path", "", "Path to Cargo.lock (unstable)")
 	removeCmd.Flags().String("manifest-path", "", "Path to Cargo.toml")
 	removeCmd.Flags().StringP("package", "p", "", "Package to remove from")
 	removeCmd.Flags().String("target", "", "Remove from target-dependencies")
 	rootCmd.AddCommand(removeCmd)
 
 	carapace.Gen(removeCmd).FlagCompletion(carapace.ActionMap{
+		"lockfile-path": carapace.ActionFiles(),
 		"manifest-path": carapace.ActionFiles(),
 		"package":       action.ActionDependencies(removeCmd, false),
 		"target":        action.ActionTargets(removeCmd, action.TargetOpts{}.Default()),
