@@ -15,6 +15,7 @@ func init() {
 	carapace.Gen(vendorCmd).Standalone()
 
 	vendorCmd.Flags().BoolP("help", "h", false, "Print help")
+	vendorCmd.Flags().String("lockfile-path", "", "Path to Cargo.lock (unstable)")
 	vendorCmd.Flags().String("manifest-path", "", "Path to Cargo.toml")
 	vendorCmd.Flags().Bool("no-delete", false, "Don't delete older crates in the vendor directory")
 	vendorCmd.Flags().Bool("respect-source-config", false, "Respect `[source]` config in `.cargo/config`")
@@ -23,6 +24,7 @@ func init() {
 	rootCmd.AddCommand(vendorCmd)
 
 	carapace.Gen(vendorCmd).FlagCompletion(carapace.ActionMap{
+		"lockfile-path": carapace.ActionFiles(),
 		"manifest-path": carapace.ActionFiles(),
 		"sync":          carapace.ActionFiles().List(","),
 	})
