@@ -17,7 +17,7 @@ func init() {
 
 	container_attachCmd.Flags().String("detach-keys", "", "Override the key sequence for detaching a container")
 	container_attachCmd.Flags().Bool("no-stdin", false, "Do not attach STDIN")
-	container_attachCmd.Flags().Bool("sig-proxy", true, "Proxy all received signals to the process")
+	container_attachCmd.Flags().Bool("sig-proxy", false, "Proxy all received signals to the process")
 	containerCmd.AddCommand(container_attachCmd)
 
 	carapace.Gen(container_attachCmd).FlagCompletion(carapace.ActionMap{
