@@ -18,7 +18,7 @@ func init() {
 	container_logsCmd.Flags().Bool("details", false, "Show extra details provided to logs")
 	container_logsCmd.Flags().BoolP("follow", "f", false, "Follow log output")
 	container_logsCmd.Flags().String("since", "", "Show logs since timestamp (e.g. \"2013-01-02T13:23:37Z\") or relative (e.g. \"42m\" for 42 minutes)")
-	container_logsCmd.Flags().StringP("tail", "n", "all", "Number of lines to show from the end of the logs")
+	container_logsCmd.Flags().StringP("tail", "n", "", "Number of lines to show from the end of the logs")
 	container_logsCmd.Flags().BoolP("timestamps", "t", false, "Show timestamps")
 	container_logsCmd.Flags().String("until", "", "Show logs before a timestamp (e.g. \"2013-01-02T13:23:37Z\") or relative (e.g. \"42m\" for 42 minutes)")
 	containerCmd.AddCommand(container_logsCmd)
