@@ -15,7 +15,7 @@ var plugin_enableCmd = &cobra.Command{
 func init() {
 	carapace.Gen(plugin_enableCmd).Standalone()
 
-	plugin_enableCmd.Flags().Int("timeout", 0, "HTTP client timeout (in seconds)")
+	plugin_enableCmd.Flags().String("timeout", "", "HTTP client timeout (in seconds)")
 	pluginCmd.AddCommand(plugin_enableCmd)
 
 	carapace.Gen(plugin_enableCmd).PositionalCompletion(
