@@ -15,7 +15,8 @@ var plugin_pushCmd = &cobra.Command{
 func init() {
 	carapace.Gen(plugin_pushCmd).Standalone()
 
-	plugin_pushCmd.Flags().Bool("disable-content-trust", true, "Skip image signing")
+	plugin_pushCmd.Flags().Bool("disable-content-trust", false, "Skip image verification (deprecated)")
+	plugin_pushCmd.Flag("disable-content-trust").Hidden = true
 	pluginCmd.AddCommand(plugin_pushCmd)
 
 	carapace.Gen(plugin_pushCmd).PositionalCompletion(
