@@ -17,7 +17,7 @@ func init() {
 
 	searchCmd.Flags().StringP("filter", "f", "", "Filter output based on conditions provided")
 	searchCmd.Flags().String("format", "", "Pretty-print search using a Go template")
-	searchCmd.Flags().Int("limit", 0, "Max number of search results")
+	searchCmd.Flags().String("limit", "", "Max number of search results")
 	searchCmd.Flags().Bool("no-trunc", false, "Don't truncate output")
 	rootCmd.AddCommand(searchCmd)
 }
