@@ -16,7 +16,7 @@ func init() {
 
 	swarm_caCmd.Flags().String("ca-cert", "", "Path to the PEM-formatted root CA certificate to use for the new cluster")
 	swarm_caCmd.Flags().String("ca-key", "", "Path to the PEM-formatted root CA key to use for the new cluster")
-	swarm_caCmd.Flags().Duration("cert-expiry", 0, "Validity period for node certificates (ns|us|ms|s|m|h)")
+	swarm_caCmd.Flags().String("cert-expiry", "", "Validity period for node certificates (ns|us|ms|s|m|h)")
 	swarm_caCmd.Flags().BoolP("detach", "d", false, "Exit immediately instead of waiting for the root rotation to converge")
 	swarm_caCmd.Flags().String("external-ca", "", "Specifications of one or more certificate signing endpoints")
 	swarm_caCmd.Flags().BoolP("quiet", "q", false, "Suppress progress output")
