@@ -17,6 +17,6 @@ func init() {
 	system_pruneCmd.Flags().BoolP("all", "a", false, "Remove all unused images not just dangling ones")
 	system_pruneCmd.Flags().String("filter", "", "Provide filter values (e.g. \"label=<key>=<value>\")")
 	system_pruneCmd.Flags().BoolP("force", "f", false, "Do not prompt for confirmation")
-	system_pruneCmd.Flags().Bool("volumes", false, "Prune volumes")
+	system_pruneCmd.Flags().Bool("volumes", false, "Prune anonymous volumes")
 	systemCmd.AddCommand(system_pruneCmd)
 }
