@@ -23,12 +23,12 @@ func ActionConfigHosts() carapace.Action {
 			return carapace.ActionMessage("failed to parse DefaultConfig: " + err.Error())
 		} else {
 			if hosts, err := config.Hosts(); err != nil {
-				return carapace.ActionMessage("failed ot loadd hosts: " + err.Error())
+				return carapace.ActionMessage("failed ot load hosts: " + err.Error())
 			} else {
 				return carapace.ActionValues(hosts...)
 			}
 		}
-	})
+	}).Tag("config hosts")
 }
 
 func ApiV3Action(cmd *cobra.Command, query string, v interface{}, transform func() carapace.Action) carapace.Action {
