@@ -32,5 +32,5 @@ func ActionDiscussionCategories(cmd *cobra.Command) carapace.Action {
 			}
 			return carapace.ActionValuesDescribed(vals...)
 		})
-	})
+	}).Tag("discussion categories")
 }
