@@ -20,8 +20,14 @@ func Execute() error {
 func init() {
 	carapace.Gen(rootCmd).Standalone()
 
-	rootCmd.PersistentFlags().Bool("help", false, "Show help for this command.")
+	rootCmd.PersistentFlags().BoolP("help", "h", false, "Show help for this command.")
+	rootCmd.PersistentFlags().StringP("repo", "R", "", "Select another repository. Can use either `OWNER/REPO` or `GROUP/NAMESPACE/REPO` format. Also accepts full URL or Git URL.")
 	rootCmd.Flags().BoolP("version", "v", false, "show glab version information")
+	rootCmd.Flag("repo").Hidden = true
+
+	carapace.Gen(rootCmd).FlagCompletion(carapace.ActionMap{
+		"repo": action.ActionRepo(rootCmd),
+	})
 
 	carapace.Gen(rootCmd).PreRun(func(cmd *cobra.Command, args []string) {
 		if aliases, err := action.LoadAliases(); err == nil {
