@@ -7,7 +7,7 @@ import (
 
 var rootCmd = &cobra.Command{
 	Use:   "goreleaser",
-	Short: "Deliver Go binaries as fast and easily as possible",
+	Short: "Release engineering, simplified",
 	Long:  "https://goreleaser.com/",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
@@ -19,7 +19,6 @@ func Execute() error {
 func init() {
 	carapace.Gen(rootCmd).Standalone()
 
-	rootCmd.PersistentFlags().Bool("debug", false, "Enable verbose mode")
 	rootCmd.PersistentFlags().Bool("verbose", false, "Enable verbose mode")
 	rootCmd.Flags().BoolP("version", "v", false, "version for goreleaser")
 }
