@@ -15,17 +15,19 @@ var bisect_runCmd = &cobra.Command{
 
 func init() {
 	carapace.Gen(bisect_runCmd).Standalone()
+	bisect_runCmd.Flags().SetInterspersed(false)
 
-	bisect_runCmd.Flags().String("command", "", "Command to run to determine whether the bug is present")
 	bisect_runCmd.Flags().Bool("find-good", false, "Whether to find the first good revision instead")
 	bisect_runCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
 	bisect_runCmd.Flags().StringSliceP("range", "r", nil, "Range of revisions to bisect")
-	bisect_runCmd.MarkFlagRequired("command")
 	bisect_runCmd.MarkFlagRequired("range")
 	bisectCmd.AddCommand(bisect_runCmd)
 
 	carapace.Gen(bisect_runCmd).FlagCompletion(carapace.ActionMap{
-		"command": bridge.ActionCarapaceBin().Split(),
-		"range":   jj.ActionRevSets(jj.RevOption{}.Default()),
+		"range": jj.ActionRevSets(jj.RevOption{}.Default()),
 	})
+
+	carapace.Gen(bisect_runCmd).PositionalAnyCompletion(
+		bridge.ActionCarapaceBin(),
+	)
 }
