@@ -14,8 +14,8 @@ var helpCmd = &cobra.Command{
 func init() {
 	carapace.Gen(helpCmd).Standalone()
 
-	helpCmd.Flags().Bool("help", false, "Print help (see more with '--help')")
-	helpCmd.Flags().StringArrayP("keyword", "k", nil, "Show help for keywords instead of commands")
+	helpCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
+	helpCmd.Flags().StringP("keyword", "k", "", "Show help for keywords instead of commands")
 	rootCmd.AddCommand(helpCmd)
 
 	helpCmd.MarkFlagsMutuallyExclusive("help", "keyword")
