@@ -8,7 +8,7 @@ import (
 
 var nextCmd = &cobra.Command{
 	Use:   "next [OPTIONS] [AMOUNT]",
-	Short: "Move the current working copy commit to the next child revision in the repository.",
+	Short: "Move the working-copy commit to the child revision",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
@@ -18,7 +18,7 @@ func init() {
 	nextCmd.Flags().Bool("conflict", false, "Jump to the next conflicted descendant")
 	nextCmd.Flags().BoolP("edit", "e", false, "Instead of creating a new working-copy commit on top of the target commit (like `jj new`), edit the target commit directly (like `jj edit`)")
 	nextCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
-	nextCmd.Flags().Bool("no-edit", false, "Instead of editing the target commit directly (like `jj edit`), create a new working-copy commit on top of the target commit (like `jj new`)")
+	nextCmd.Flags().BoolP("no-edit", "n", false, "The inverse of `--edit`")
 	rootCmd.AddCommand(nextCmd)
 
 	nextCmd.MarkFlagsMutuallyExclusive("edit", "no-edit")
