@@ -14,9 +14,6 @@ var util_completionCmd = &cobra.Command{
 func init() {
 	carapace.Gen(util_completionCmd).Standalone()
 
-	util_completionCmd.Flags().Bool("bash", false, "Print a completion script for Bash")
-	util_completionCmd.Flags().Bool("fish", false, "Print a completion script for Fish")
 	util_completionCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
-	util_completionCmd.Flags().Bool("zsh", false, "Print a completion script for Zsh")
 	utilCmd.AddCommand(util_completionCmd)
 }
