@@ -7,13 +7,14 @@ import (
 )
 
 var addons_disableCmd = &cobra.Command{
-	Use:   "disable",
+	Use:   "disable ADDON_NAME",
 	Short: "Disables the addon w/ADDON_NAME within minikube (example: minikube addons disable dashboard). For a list of available addons use: minikube addons list ",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(addons_disableCmd).Standalone()
+
 	addonsCmd.AddCommand(addons_disableCmd)
 
 	carapace.Gen(addons_disableCmd).PositionalCompletion(
