@@ -6,13 +6,13 @@ import (
 )
 
 var cacheCmd = &cobra.Command{
-	Use:     "cache",
-	Short:   "Add, delete, or push a local image into minikube",
-	GroupID: "images",
-	Run:     func(cmd *cobra.Command, args []string) {},
+	Use:   "cache",
+	Short: "Manage cache for images",
+	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(cacheCmd).Standalone()
+
 	rootCmd.AddCommand(cacheCmd)
 }
