@@ -7,18 +7,19 @@ import (
 )
 
 var config_defaultsCmd = &cobra.Command{
-	Use:   "defaults",
+	Use:   "defaults PROPERTY_NAME",
 	Short: "Lists all valid default values for PROPERTY_NAME",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(config_defaultsCmd).Standalone()
-	config_defaultsCmd.Flags().String("output", "table", "Output format. Accepted values: [json]")
+
+	config_defaultsCmd.Flags().StringP("output", "o", "", "Output format. Accepted values: [json, yaml]")
 	configCmd.AddCommand(config_defaultsCmd)
 
 	carapace.Gen(config_defaultsCmd).FlagCompletion(carapace.ActionMap{
-		"output": carapace.ActionValues("json"),
+		"output": carapace.ActionValues("json", "yaml"),
 	})
 
 	carapace.Gen(config_defaultsCmd).PositionalCompletion(
