@@ -6,7 +6,7 @@ import (
 )
 
 var profileCmd = &cobra.Command{
-	Use:     "profile",
+	Use:     "profile [MINIKUBE_PROFILE_NAME].  You can return to the default minikube profile by running `minikube profile default`",
 	Short:   "Get or list the current profiles (clusters)",
 	GroupID: "configuration",
 	Run:     func(cmd *cobra.Command, args []string) {},
@@ -14,5 +14,6 @@ var profileCmd = &cobra.Command{
 
 func init() {
 	carapace.Gen(profileCmd).Standalone()
+
 	rootCmd.AddCommand(profileCmd)
 }
