@@ -7,15 +7,16 @@ import (
 )
 
 var override_unsetCmd = &cobra.Command{
-	Use:   "unset",
-	Short: "Remove the override toolchain for a directory",
-	Run:   func(cmd *cobra.Command, args []string) {},
+	Use:     "unset",
+	Short:   "Remove the override toolchain for a directory",
+	Aliases: []string{"remove", "rm", "delete", "del"},
+	Run:     func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(override_unsetCmd).Standalone()
 
-	override_unsetCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	override_unsetCmd.Flags().BoolP("help", "h", false, "Print help")
 	override_unsetCmd.Flags().Bool("nonexistent", false, "Remove override toolchain for all nonexistent directories")
 	override_unsetCmd.Flags().String("path", "", "Path to the directory")
 	overrideCmd.AddCommand(override_unsetCmd)
