@@ -7,14 +7,14 @@ import (
 
 var self_uninstallCmd = &cobra.Command{
 	Use:   "uninstall",
-	Short: "Uninstall rustup.",
+	Short: "Uninstall rustup",
 	Run:   func(cmd *cobra.Command, args []string) {},
 }
 
 func init() {
 	carapace.Gen(self_uninstallCmd).Standalone()
 
-	self_uninstallCmd.Flags().BoolP("help", "h", false, "Prints help information")
+	self_uninstallCmd.Flags().BoolP("help", "h", false, "Print help")
 	self_uninstallCmd.Flags().BoolS("y", "y", false, "")
 	selfCmd.AddCommand(self_uninstallCmd)
 }
