@@ -11,7 +11,7 @@ import (
 //	carapace (https://github.com/carapace-sh/carapace)
 //	carapace-bin (https://github.com/carapace-sh/carapace-bin)
 func ActionRemotes() carapace.Action {
-	return carapace.ActionExecCommand("jj", "git", "remote", "list")(func(output []byte) carapace.Action {
+	return actionExecJJ("git", "remote", "list")(func(output []byte) carapace.Action {
 		lines := strings.Split(string(output), "\n")
 		vals := make([]string, 0)
 		for _, line := range lines[:len(lines)-1] {
